fnss.topologies.topology.DirectedTopology.add_edge — FNSS 0.1.0 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.1.0 documentation »

# fnss.topologies.topology.DirectedTopology.add_edge

`DirectedTopology.` `add_edge`(u, v, attr_dict=None, **attr)

  Add an edge between u and v.

  The nodes u and v will be automatically added if they are not already in the graph.

  Edge attributes can be specified with keywords or by providing a dictionary with key/value pairs. See examples below.

  Parameters : | u,v : nodes Nodes can be, for example, strings or numbers. Nodes must be hashable (and not None) Python objects. attr_dict : dictionary, optional (default= no attributes) Dictionary of edge attributes. Key/value pairs will update existing data associated with the edge. attr : keyword arguments, optional Edge data (or labels or objects) can be assigned using keyword arguments.

  See also

  `add_edges_from`
    add a collection of edges

  Notes

  Adding an edge that already exists updates the edge data.

  Many NetworkX algorithms designed for weighted graphs use as the edge weight a numerical value assigned to a keyword which by default is ‘weight’.

  Examples

  The following all add the edge e=(1,2) to graph G:

      >>> G = nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
      >>> e = (1,2)
      >>> G.add_edge(1, 2)           # explicit two-node form
      >>> G.add_edge(*e)             # single edge as tuple of two nodes
      >>> G.add_edges_from( [(1,2)] ) # add edges from iterable container

  Associate data to edges using keywords:

      >>> G.add_edge(1, 2, weight=3)
      >>> G.add_edge(1, 3, weight=7, capacity=15, length=342.7)

### Navigation

- index
- modules |
- modules |
- FNSS 0.1.0 documentation »